Index: src/wp-includes/comment-template.php
===================================================================
--- src/wp-includes/comment-template.php	(revision 28395)
+++ src/wp-includes/comment-template.php	(working copy)
@@ -1052,7 +1052,7 @@
  * and the post ID respectively.
  *
  * The $file path is passed through a filter hook called, 'comments_template'
- * which includes the TEMPLATEPATH and $file combined. Tries the $filtered path
+ * which includes the template path and $file combined. Tries the $filtered path
  * first and if it fails it will require the default comment template from the
  * default theme. If either does not exist, then the WordPress process will be
  * halted. It is advised for that reason, that the default theme is not deleted.
@@ -1137,7 +1137,7 @@
 	if ( !defined('COMMENTS_TEMPLATE') )
 		define('COMMENTS_TEMPLATE', true);
 
-	$theme_template = STYLESHEETPATH . $file;
+	$theme_template = get_stylesheet_directory() . $file;
 	/**
 	 * Filter the path to the theme template file used for the comments template.
 	 *
@@ -1148,8 +1148,8 @@
 	$include = apply_filters( 'comments_template', $theme_template );
 	if ( file_exists( $include ) )
 		require( $include );
-	elseif ( file_exists( TEMPLATEPATH . $file ) )
-		require( TEMPLATEPATH . $file );
+	elseif ( file_exists( get_template_directory() . $file ) )
+		require( get_template_directory() . $file );
 	else // Backward compat code will be removed in a future release
 		require( ABSPATH . WPINC . '/theme-compat/comments.php');
 }
Index: src/wp-includes/default-constants.php
===================================================================
--- src/wp-includes/default-constants.php	(revision 28395)
+++ src/wp-includes/default-constants.php	(working copy)
@@ -296,12 +296,16 @@
 	/**
 	 * Filesystem path to the current active template directory
 	 * @since 1.5.0
+	 * @deprecated 4.0
+	 * @deprecated Use get_template_directory()
 	 */
 	define('TEMPLATEPATH', get_template_directory());
 
 	/**
 	 * Filesystem path to the current active template stylesheet directory
 	 * @since 2.1.0
+	 * @deprecated 4.0
+	 * @deprecated Use get_stylesheet_directory()
 	 */
 	define('STYLESHEETPATH', get_stylesheet_directory());
 
Index: src/wp-includes/theme.php
===================================================================
--- src/wp-includes/theme.php	(revision 28395)
+++ src/wp-includes/theme.php	(working copy)
@@ -128,7 +128,7 @@
  * @return bool true if a child theme is in use, false otherwise.
  **/
 function is_child_theme() {
-	return ( TEMPLATEPATH !== STYLESHEETPATH );
+	return get_template_directory() !== get_stylesheet_directory();
 }
 
 /**
Index: src/wp-settings.php
===================================================================
--- src/wp-settings.php	(revision 28395)
+++ src/wp-settings.php	(working copy)
@@ -322,10 +322,12 @@
 
 // Load the functions for the active theme, for both parent and child theme if applicable.
 if ( ! defined( 'WP_INSTALLING' ) || 'wp-activate.php' === $pagenow ) {
-	if ( TEMPLATEPATH !== STYLESHEETPATH && file_exists( STYLESHEETPATH . '/functions.php' ) )
-		include( STYLESHEETPATH . '/functions.php' );
-	if ( file_exists( TEMPLATEPATH . '/functions.php' ) )
-		include( TEMPLATEPATH . '/functions.php' );
+	if ( is_child_theme() && file_exists( get_stylesheet_directory() . '/functions.php' ) ) {
+		include get_stylesheet_directory() . '/functions.php';
+	}
+	if ( file_exists( get_template_directory() . '/functions.php' ) ) {
+		include get_template_directory() . '/functions.php';
+	}
 }
 
 /**

Index: src/wp-includes/template.php
===================================================================
--- src/wp-includes/template.php	(revision 28395)
+++ src/wp-includes/template.php	(working copy)
@@ -449,7 +449,7 @@
 /**
  * Retrieve the name of the highest priority template file that exists.
  *
  * Searches in the STYLESHEETPATH before TEMPLATEPATH so that themes which
  * inherit from a parent theme can just overload one file.
  *
  * @since 2.7.0
@@ -464,11 +464,11 @@
 	foreach ( (array) $template_names as $template_name ) {
 		if ( !$template_name )
 			continue;
-		if ( file_exists(STYLESHEETPATH . '/' . $template_name)) {
-			$located = STYLESHEETPATH . '/' . $template_name;
+		if ( file_exists( get_stylesheet_directory() . '/' . $template_name ) ) {
+			$located = get_stylesheet_directory() . '/' . $template_name;
 			break;
-		} else if ( file_exists(TEMPLATEPATH . '/' . $template_name) ) {
-			$located = TEMPLATEPATH . '/' . $template_name;
+		} else if ( file_exists( get_template_directory() . '/' . $template_name ) ) {
+			$located = get_template_directory() . '/' . $template_name;
 			break;
 		}
 	}
@@ -449,7 +449,7 @@
  * Retrieve the name of the highest priority template file that exists.
  *
- * Searches in the STYLESHEETPATH before TEMPLATEPATH so that themes which
+ * Searches in the stylesheet path before template path so that themes which
  * inherit from a parent theme can just overload one file.
  *